@@ -47,18 +47,25 @@ class PocketCameraWindow(QtWidgets.QDialog):
 		grpColorsLayout.setContentsMargins(-1, 3, -1, -1)
 		self.rowColors1 = QtWidgets.QHBoxLayout()
 		self.optColorBW = QtWidgets.QRadioButton("&Grayscale")
+		self.optColorBW.setToolTip("Generic grayscale palette")
 		self.connect(self.optColorBW, QtCore.SIGNAL("clicked()"), self.SetColors)
 		self.optColorDMG = QtWidgets.QRadioButton("&DMG")
+		self.optColorDMG.setToolTip("Original Game Boy screen palette")
 		self.connect(self.optColorDMG, QtCore.SIGNAL("clicked()"), self.SetColors)
 		#self.optColorMGB = QtWidgets.QRadioButton("&MGB")
+		#self.optColorMGB.setToolTip("Game Boy Pocket palette")
 		#self.connect(self.optColorMGB, QtCore.SIGNAL("clicked()"), self.SetColors)
 		self.optColorSGB = QtWidgets.QRadioButton("&SGB")
+		self.optColorSGB.setToolTip("Super Game Boy palette")
 		self.connect(self.optColorSGB, QtCore.SIGNAL("clicked()"), self.SetColors)
 		self.optColorCGB1 = QtWidgets.QRadioButton("CGB &1")
+		self.optColorCGB1.setToolTip("Japanese Pocket Camera palette")
 		self.connect(self.optColorCGB1, QtCore.SIGNAL("clicked()"), self.SetColors)
 		self.optColorCGB2 = QtWidgets.QRadioButton("CGB &2")
+		self.optColorCGB2.setToolTip("Golden Limited Edition Game Boy Camera palette")
 		self.connect(self.optColorCGB2, QtCore.SIGNAL("clicked()"), self.SetColors)
 		self.optColorCGB3 = QtWidgets.QRadioButton("CGB &3")
+		self.optColorCGB3.setToolTip("Non-Japanese Game Boy Camera palette")
 		self.connect(self.optColorCGB3, QtCore.SIGNAL("clicked()"), self.SetColors)
 		self.rowColors1.addWidget(self.optColorBW)
 		self.rowColors1.addWidget(self.optColorDMG)
